from setuptools import setup

setup(name='tolib',
      version='1.1',
      description='Математический модуль',
      packages=['tolib'],
      author_email='tolibaevrinat4@gmail.com',
      zip_safe=False)